<style>

  img {
    height: auto;
    max-width: 100%;
  }

  a {
    color: #212121;
    text-decoration: underline;
    text-decoration-color: #ff0000;
    transition: all 0.2s ease-in-out;
  }

  a:hover {
    color: #ff0000 !important;
    text-decoration-color: #212121 !important;
  }

  a.btn {
    background: #ff0000;
    border-radius: 2px;
    color: #ffffff;
    display: inline-block;
    padding: 8px 20px;
    text-decoration: none;
  }

  a.btn:hover {
    background: #b51f1f !important;
    color: #ffffff !important;
  }

  a.btn.btn-action {
    background: #ffffff;
    border: 1px solid #707070;
    color: #212121;
  }

  a.btn.btn-action:hover {
    background: #E6E6E6 !important;
    color: #212121 !important;
  }

  u + #body a {
    color: #212121;
    text-decoration: underline;
    text-decoration-color: #ff0000;
    font-size: inherit !important;
    font-family: inherit !important;
    font-weight: inherit !important;
    line-height: inherit !important;
  }

  .template-container {
    max-width: 640px !important;
  }

  @media only screen and (min-width:768px) {
    .template-container {
      width:640px !important;
    }
  }

</style>
