{% load i18n %}

<tr>
  <td style="background: #e6e6e6; padding: 5px 0; text-align: center;">
    <p style="font-size: 13px; line-height: 17px; margin: 0; text-align: center;">
      <a href="{{ ONLINE_VERSION_LINK }}" style="color: #707070; text-decoration: underline;">
        {% trans "ONLINE_VERSION" %}
      </a>
    </p>
  </td>
</tr>
