{% extends "epflmail/base.html" %}

{% block content %}

  <table class="template-container" style="border-collapse: collapse; max-width: 640px; width: 100%;" width="100%">

    {% block online %}
    {% endblock %}
    {% include 'epflmail/includes/header.inc.html' %}
    {% include 'epflmail/includes/spacer.inc.html' %}

    <tr>
      <td>
        {% block main %}
        {% endblock %}
      </td>
    </tr>

    {% include 'epflmail/includes/spacer.inc.html' %}
    {% include 'epflmail/includes/copyright.inc.html' %}

    {% block unsubscribe %}
    {% endblock %}

  </table>

{% endblock %}
