{% load i18n %}

<td style="border-bottom: 2px solid #d5d5d5; text-align: right;" valign="middle">
  {% if APP_TITLE %}
    <p style="font-size: 16px; font-weight: bold; margin: 0; text-align: right;">
      <img alt="▪" height="7" src="https://web2018.epfl.ch/6.1.1/icons/square.png" style="margin: 0" width="8">
      <span style="margin-left: 5px">
        {{ APP_TITLE }}
      </span>
    </p>
  {% endif %}
</td>
