{% load i18n %}

<tr>
  <td>
    <table style="border-collapse: collapse; max-width: 640px; width: 100%;" width="100%">
      <tr>
        {% include 'epflmail/includes/logo.inc.html' %}
        {% include 'epflmail/includes/app-title.inc.html' %}
      </tr>
    </table>
  </td>
</tr>
