{% load i18n %}

{% get_current_language as LANGUAGE_CODE %}

<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE }}">

  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="initial-scale=1.0, width=device-width">
    <title>{% block title %}{% endblock %}</title>
    {% include 'epflmail/includes/style.inc.html' %}
    {% block extra_head %}{% endblock %}
  </head>

  <body id="body" style="border: 0; margin: 0; padding: 0;">
    <table style="border-collapse: collapse; color: #212121; font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif; font-size: 15px; line-height: 1.3em; max-width: 100%;" width="100%">
      <tr>
        <td align="center" style="padding: 20px;">
          {% block content %}{% endblock %}
        </td>
      </tr>
    </table>
  </body>

</html>
